You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@spamassassin.apache.org by fe...@apache.org on 2004/07/16 20:57:21 UTC

svn commit: rev 22977 - in spamassassin/trunk/lib/Mail: . SpamAssassin SpamAssassin/Message

Author: felicity
Date: Fri Jul 16 11:57:20 2004
New Revision: 22977

Modified:
   spamassassin/trunk/lib/Mail/SpamAssassin.pm
   spamassassin/trunk/lib/Mail/SpamAssassin/ArchiveIterator.pm
   spamassassin/trunk/lib/Mail/SpamAssassin/Constants.pm
   spamassassin/trunk/lib/Mail/SpamAssassin/Message.pm
   spamassassin/trunk/lib/Mail/SpamAssassin/Message/Node.pm
   spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm
Log:
reverting change from 22962.  needs a bugzilla ticket and dev vote.

Modified: spamassassin/trunk/lib/Mail/SpamAssassin.pm
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin.pm	Fri Jul 16 11:57:20 2004
@@ -837,7 +837,7 @@
   my ($self, $mail_obj) = @_;
   local ($_);
 
-  my $mbox = $mail_obj->get_mbox_separator() || '';
+  my $mbox = $mail_obj->get_mbox_seperator() || '';
 
   dbg("Removing Markup");
 

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/ArchiveIterator.pm
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/ArchiveIterator.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/ArchiveIterator.pm	Fri Jul 16 11:57:20 2004
@@ -599,7 +599,7 @@
 	# skip mbx headers to the first email...
 	seek(INPUT, 2048, 0) ;
 
-        my $sep = MBX_SEPARATOR;
+        my $sep = MBX_SEPERATOR;
     
 	while (<INPUT>) {
 	    if ($_ =~ /$sep/) {
@@ -699,7 +699,7 @@
     seek(INPUT, $offset, 0) ;
     
     while (<INPUT>) {
-	last if ($_ =~ MBX_SEPARATOR) ;
+	last if ($_ =~ MBX_SEPERATOR) ;
 	
 	# skip mails that are too big
 	if (! $self->{opt_all} && @msg > BIG_LINES) {

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Constants.pm
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Constants.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Constants.pm	Fri Jul 16 11:57:20 2004
@@ -34,7 +34,7 @@
 );
 # These are generic constants that may be used across several modules
 @SA_VARS = qw(
-	META_TEST_MIN_PRIORITY HARVEST_DNSBL_PRIORITY MBX_SEPARATOR
+	META_TEST_MIN_PRIORITY HARVEST_DNSBL_PRIORITY MBX_SEPERATOR
 );
 
 %EXPORT_TAGS = (
@@ -168,9 +168,9 @@
 use constant META_TEST_MIN_PRIORITY => 500;
 use constant HARVEST_DNSBL_PRIORITY => 500;
 
-# regular expression that matches message separators in The University of
-# Washington's MBX mailbox format
-use constant MBX_SEPARATOR => qr/([\s|\d]\d-[a-zA-Z]{3}-\d{4}\s\d{2}:\d{2}:\d{2}.*),(\d+);([\da-f]{12})-(\w{8})/;
+# Regular expression that matches message sperators in The University of
+# Washington's MBX mailbox format...
+use constant MBX_SEPERATOR => qr/([\s|\d]\d-[a-zA-Z]{3}-\d{4}\s\d{2}:\d{2}:\d{2}.*),(\d+);([\da-f]{12})-(\w{8})/ ;
 # $1 = datestamp (str)
 # $2 = size of message in bytes (int)
 # $3 = message status - binary (hex)

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Message.pm
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Message/Node.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Message/Node.pm	Fri Jul 16 11:57:20 2004
@@ -577,7 +577,7 @@
 Retrieve all headers.  Each header will have a newline at the end and
 will be unfolded.  The first parameter (optional) is whether or not to
 return the raw headers, and the second parameter (optional) is whether
-or not to include the mbox separator.
+or not to include the mbox seperator.
 
 If get_all_header() is called in an array context, an array will be
 returned with each header entry in a different element.  In a scalar

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm	Fri Jul 16 11:57:20 2004
@@ -625,7 +625,7 @@
 sub rewrite_mail {
   my ($self) = @_;
 
-  my $mbox = $self->{msg}->get_mbox_separator() || '';
+  my $mbox = $self->{msg}->get_mbox_seperator() || '';
   if ($self->{is_spam} && $self->{conf}->{report_safe}) {
     return $mbox.$self->rewrite_report_safe();
   }
--- spamassassin/trunk/lib/Mail/SpamAssassin/Message.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Message.pm	Fri Jul 16 11:57:20 2004
@@ -129,8 +129,8 @@
 	# mbox formated mailbox
 	$self->{'mbox_sep'} = $last;
 	next;
-    } elsif ($last =~ MBX_SEPARATOR) {
-	# Munge the mbx message separator into mbox format as a sort of
+    } elsif ($last =~ MBX_SEPERATOR) {
+	# Munge the mbx message seperator into mbox format as a sort of
 	# de facto portability standard in SA's internals.  We need to
 	# to this so that Mail::SpamAssassin::Util::parse_rfc822_date
 	# can parse the date string...
@@ -303,14 +303,14 @@
   }
 }
 
-=item get_mbox_separator()
+=item get_mbox_seperator()
 
-Returns the mbox separator found in the message, or undef if there
+Returns the mbox seperator found in the message, or undef if there
 wasn't one.
 
 =cut
 
-sub get_mbox_separator {
+sub get_mbox_seperator {
   return $_[0]->{mbox_sep};
 }
 

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Message/Node.pm
==============================================================================